@@ -41,7 +41,9 @@
 */
 
 #include <math.h>
+
 #include "pgm.h"
+#include "mallocvar.h"
 
 #define RADIX 2.0
 #define EPSILON 0.000000001
@@ -73,7 +75,7 @@ vector (int nl, int nh)
 {
   float *v;
 
-  v = (float *) malloc ((unsigned) (nh - nl + 1) * sizeof (float));
+  MALLOCARRAY(v, (unsigned) (nh - nl + 1));
   if (v == NULL)
     pm_error("Unable to allocate memory for a vector.");
   return v - nl;
@@ -89,7 +91,7 @@ matrix (int nrl, int nrh, int ncl, int nch)
   float **m;
 
   /* allocate pointers to rows */
-  m = (float **) malloc ((unsigned) (nrh - nrl + 1) * sizeof (float *));
+  MALLOCARRAY(m, (unsigned) (nrh - nrl + 1));
   if (m == NULL)
     pm_error("Unable to allocate memory for a matrix.");
 
@@ -98,7 +100,7 @@ matrix (int nrl, int nrh, int ncl, int nch)
   /* allocate rows and set pointers to them */
   for (i = nrl; i <= nrh; i++)
   {
-    m[i] = (float *) malloc ((unsigned) (nch - ncl + 1) * sizeof (float));
+    MALLOCARRAY(m[i], (unsigned) (nch - ncl + 1));
     if (m[i] == NULL)
       pm_error("Unable to allocate memory for a matrix row.");
     m[i] -= ncl;
@@ -747,8 +749,8 @@ f13_icorr (float **P, int Ng)
     hx -= px[i] * log10 (px[i] + EPSILON);
     hy -= py[i] * log10 (py[i] + EPSILON);
   }
-/*  fprintf(stderr,"hx=%f\thxy2=%f\n",hx,hxy2); */
-  return (sqrt (abs (1 - exp (-2.0 * (hxy2 - hxy)))));
+  /* fprintf(stderr,"hx=%f\thxy2=%f\n",hx,hxy2); */
+  return (sqrt (fabs (1 - exp (-2.0 * (hxy2 - hxy)))));
 }
 
 static float 
