@@ -576,10 +576,12 @@ sub libSuffix($) {
 #-----------------------------------------------------------------------------
     my $suffix;
 
-    if ($platform eq "windows") {
-        $suffix = ".a";
+    if ($platform eq 'windows') {
+        $suffix = '.a';
+    } elsif ($platform eq 'darwin') {
+        $suffix = '.dylib';
     } else {
-        $suffix = ".so";
+        $suffix = '.so';
     }
 }
 
@@ -1813,7 +1815,7 @@ if ($platform eq "GNU") {
     push(@Makefile_config, 'CFLAGS_SHLIB = -fno-common', "\n");
     push(@Makefile_config, "LDSHLIB = ",
          "-dynamiclib ",
-         '-install_name $(NETPBM_RUNTIME_PATH)/libnetpbm.$(MAJ).dylib', 
+         '-install_name $(NETPBMLIB_RUNTIME_PATH)/libnetpbm.$(MAJ).dylib', 
          "\n");
 #    push(@Makefile_config, "INSTALL = install\n");
 } else {
