@@ -193,7 +193,8 @@ main(int argc, char *argv[]) {
                         (int)tuplerow2[col][plane2];
                     break;
                 case FN_MULTIPLY:
-                    result = tuplerow1[col][plane1] * tuplerow2[col][plane2] /
+                    result = (double)tuplerow1[col][plane1] *
+                        tuplerow2[col][plane2] /
                         outpam.maxval;
                     break;
                 case FN_DIFFERENCE:
