@@ -24,6 +24,7 @@
 ******************************************************************************/
 
 #include <math.h>
+#include <assert.h>
 
 #include "pam.h"
 #include "pammap.h"
@@ -208,6 +209,8 @@ initSampleCompare(void) {
     samplecompare[0].fn = compareplane0;
     samplecompare[1].fn = compareplane1;
     samplecompare[2].fn = compareplane2;
+
+    assert(MAXDEPTH == 3);
 }
 
 
@@ -521,6 +524,10 @@ splitBox(boxVector             const bv,
     int lowersum;
     /* Number of pixels whose value is "less than" the median */
 
+    if (depth > MAXDEPTH)
+        pm_error("Depth of image (%u) is too high.  Maximum depth "
+                 "this program can process is %u", depth, MAXDEPTH);
+
     findBoxBoundaries(colorfreqtable, depth, boxStart, boxSize, 
                       minval, maxval);
 
